==> yml-2.1.0.tar.gz: yml-2.1.0/src/Yml/Core/DistributeList.cc <==
/* -*- mode: c++; c-file-style: "engine"; c-basic-offset: 4; indent-tabs-mode: nil -*- */
/****************************************************************************
 * Copyright Maxime Hugues 2011
 *
 * Maxime Hugues
 *   Maxime.Hugues@gmail.com or Maxime.Hugues@inria.fr
 *	 INRIA Saclay
 *   PCRI - Bureau 142
 *   Rue Noetzlin
 *   91190 Gif-sur-Yvette France
 *
 *
 *
 * This software is a computer program whose purpose is to [describe
 * functionalities and technical features of your software].
 * 
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 ****************************************************************************/

/**
 * @file
 * @brief Class Distribute declaration
 *
 * 2011-09-20
 * Maxime Hugues
 */
#include "DistributeList.hh"
#ifndef HAVE_INLINE
#define inline
#include "DistributeList.icc"
#undef inline
#endif
#ifdef HAVE_CONFIG_H
#include <yml_config.hh> 
#endif 
#include <string>
#include <vector>
#include <sstream>
#include <cstdlib>
#include <iostream>

namespace Yml 
{
namespace Core
{
Util::XMLSerializer& DistributeList::toXML(Util::XMLSerializer& stream) const
{
	stream.openTag("distribute");
	std::vector<DistributeParam>::const_iterator end = mDistribute.end();
	std::vector<DistributeParam>::const_iterator iter = mDistribute.begin();
	for (;iter != end ; ++iter)
	{
		stream.openTag("param");

		std::vector<ParameterMapping> mapping = iter->getMapping();
		std::string paramMap;

		for (int i=0; i < mapping.size() ; i++)
		{
			if(i!=0) paramMap += ',';
			switch(mapping[i])
			{
			case PARAM_MAP_BLOCK:
				paramMap += "block";
				break;
			case PARAM_MAP_CYCLIC:
				paramMap += "cyclic";
				break;
			}
		}

		std::string align = iter->getDataAlign() + ":" + iter->getTemplateAlign();

		std::vector<int> vSize = iter->getSize();
		std::ostringstream size;

		size << "(";

		for (int i=0; i < vSize.size() ; i++)
		{
			if(i!=0) size << ',';

			size << vSize[i];
		}
		size << ")";

		stream.attribute("template", paramMap);
		stream.attribute("align", align);
		stream.attribute("name", iter->getName() + size.str())
								  .closeTag();
	}
	stream.closeTag();
	return stream;
}

Util::CSVSerializer& DistributeList::toCSV(Util::CSVSerializer& stream) const
{
	std::vector<DistributeParam>::const_iterator end = mDistribute.end();
	std::vector<DistributeParam>::const_iterator iter = mDistribute.begin();
	/*for (;iter != end ; ++iter)
	{
		stream.newRow();
		switch(iter->getMapping())
		{
		case PARAM_MAP_BLOCK:
			stream.cell("block");
			break;
		case PARAM_MAP_CYCLIC:
			stream.cell("cyclic");
			break;
		}
		stream.cell(iter->getName());
	}*/
	return stream;
}

DistributeList_csvHandler::DistributeList_csvHandler(DistributeList& list)
: mList(list), mCellId(0)
{
}

void DistributeList_csvHandler::rowStart()
{
	mList.add(DistributeParam());
	mCellId = 0;
}

void DistributeList_csvHandler::cell(const string& value)
{
	/*switch(mCellId)
	{
	case 0: // Mapping
		if (value == "block")
		{
			mList.mDistribute.back().setMapping(PARAM_MAP_BLOCK);
		}
		else if (value == "cyclic")
		{
			mList.mDistribute.back().setMapping(PARAM_MAP_CYCLIC);
		}
		break;

	case 1: // Name
		mList.mDistribute.back().setName(value);
		break;

	}
	++mCellId;*/
}
DistributeList_xmlHandler::DistributeList_xmlHandler(DistributeList& list)
: mList(list)
{ 
}

bool DistributeList_xmlHandler::isHandled(const string& element)
{
	if (element == "param")
		return true;
	return false;
}
void DistributeList_xmlHandler::elementStart(const string& element, const Util::Properties& attributes)
{
	if (element == "param")
	{

		const string& distribute = attributes.stringValue("template", "block"); /* Extend for template tokenizing */
		std::istringstream distributeStream(distribute);
		std::vector<ParameterMapping> mapping;
		std::string distributeName;

		while ( std::getline(distributeStream,distributeName,',') )
		{
			if (distributeName == "block")
				mapping.push_back(PARAM_MAP_BLOCK);
			else if (distributeName == "cyclic")
				mapping.push_back(PARAM_MAP_CYCLIC);
			else
				mapping.push_back(PARAM_MAP_BLOCK);

		}

		string align = attributes.stringValue("align");
		std::istringstream alignStream(align);
		std::string DataAlign;
		std:string TemplateAlign;
		std::string alignName;

		std::getline(alignStream,alignName,':');
		DataAlign = alignName;
		std::getline(alignStream,alignName,':');
		TemplateAlign = alignName;


		string variableNames = attributes.stringValue("name");
		std::istringstream nameStream(variableNames);
		std::string nameAndsize;

		while ( std::getline(nameStream,nameAndsize,';') )
		{
			mList.mDistribute.push_back(DistributeParam());
			DistributeParam& ref = mList.mDistribute.back();

			std::string copyNameandSize(nameAndsize);
			std::istringstream tmpStream(copyNameandSize);
			std::string name;
			std::getline(tmpStream,name,'(');

			copyNameandSize.erase(copyNameandSize.begin(),copyNameandSize.begin()+name.size()+1);
			copyNameandSize.erase(copyNameandSize.end()-1,copyNameandSize.end());

			std::istringstream sizeStream(copyNameandSize);
			std::vector<int> vsize;
			std::string size;
			while ( std::getline(sizeStream,size,',') )
			{
				vsize.push_back(atoi(size.c_str()));
			}
			ref.setSize(vsize);
			ref.setName(name);
			ref.setMapping(mapping);
			ref.setDataAlign(DataAlign);
			ref.setTemplateAlign(TemplateAlign);

		}


	}
}

}
}

==> yml-2.2.0.tar.gz: yml-2.2.0/src/Yml/Core/DistributeList.cc <==
/* -*- mode: c++; c-file-style: "engine"; c-basic-offset: 4; indent-tabs-mode: nil -*- */
/****************************************************************************
 * Copyright Maxime Hugues 2011
 *
 * Maxime Hugues
 *   Maxime.Hugues@gmail.com or Maxime.Hugues@inria.fr
 *	 INRIA Saclay
 *   PCRI - Bureau 142
 *   Rue Noetzlin
 *   91190 Gif-sur-Yvette France
 *
 *
 *
 * This software is a computer program whose purpose is to [describe
 * functionalities and technical features of your software].
 * 
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use, 
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info". 
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability. 
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or 
 * data to be ensured and,  more generally, to use and operate it in the 
 * same conditions as regards security. 
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 ****************************************************************************/

/**
 * @file
 * @brief Class Distribute declaration
 *
 * 2011-09-20
 * Maxime Hugues
 */
#include "DistributeList.hh"
#ifndef HAVE_INLINE
#define inline
#include "DistributeList.icc"
#undef inline
#endif
#ifdef HAVE_CONFIG_H
#include <yml_config.hh> 
#endif 
#include <string>
#include <vector>
#include <sstream>
#include <cstdlib>
#include <iostream>

namespace Yml 
{
namespace Core
{
Util::XMLSerializer& DistributeList::toXML(Util::XMLSerializer& stream) const
{
	stream.openTag("distribute");
	std::vector<DistributeParam>::const_iterator end = mDistribute.end();
	std::vector<DistributeParam>::const_iterator iter = mDistribute.begin();
	for (;iter != end ; ++iter)
	{
		stream.openTag("param");

		std::vector<ParameterMapping> mapping = iter->getMapping();
		std::string paramMap;

		paramMap = iter->getTemplateName() + "(";


		for (int i=0; i < mapping.size() ; i++)
		{
			if(i!=0) paramMap += ',';
			switch(mapping[i])
			{
			case PARAM_MAP_BLOCK:
				paramMap += "block";
				break;
			case PARAM_MAP_CYCLIC:
				paramMap += "cyclic";
				break;
			}
		}

		paramMap += ")";

		std::string align = iter->getDataAlign() + ":" + iter->getTemplateAlign();

		std::vector<int> vSize = iter->getSize();
		std::ostringstream size;

		size << "(";

		for (size_t i=0; i < vSize.size() ; i++)
		{
			if(i!=0) size << ',';

			size << vSize[i];
		}
		size << ")";

		stream.attribute("template", paramMap);
		stream.attribute("align", align);
		stream.attribute("name", iter->getName() + size.str())
										  .closeTag();
	}
	stream.closeTag();
	return stream;
}

Util::CSVSerializer& DistributeList::toCSV(Util::CSVSerializer& stream) const
{
	std::vector<DistributeParam>::const_iterator end = mDistribute.end();
	std::vector<DistributeParam>::const_iterator iter = mDistribute.begin();
	/*for (;iter != end ; ++iter)
	{
		stream.newRow();
		switch(iter->getMapping())
		{
		case PARAM_MAP_BLOCK:
			stream.cell("block");
			break;
		case PARAM_MAP_CYCLIC:
			stream.cell("cyclic");
			break;
		}
		stream.cell(iter->getName());
	}*/
	return stream;
}

DistributeList_csvHandler::DistributeList_csvHandler(DistributeList& list)
: mList(list), mCellId(0)
{
}

void DistributeList_csvHandler::rowStart()
{
	mList.add(DistributeParam());
	mCellId = 0;
}

void DistributeList_csvHandler::cell(const string& value)
{
	/*switch(mCellId)
	{
	case 0: // Mapping
		if (value == "block")
		{
			mList.mDistribute.back().setMapping(PARAM_MAP_BLOCK);
		}
		else if (value == "cyclic")
		{
			mList.mDistribute.back().setMapping(PARAM_MAP_CYCLIC);
		}
		break;

	case 1: // Name
		mList.mDistribute.back().setName(value);
		break;

	}
	++mCellId;*/
}
DistributeList_xmlHandler::DistributeList_xmlHandler(DistributeList& list)
: mList(list)
{ 
}

bool DistributeList_xmlHandler::isHandled(const string& element)
{
	if (element == "param")
		return true;
	return false;
}
void DistributeList_xmlHandler::elementStart(const string& element, const Util::Properties& attributes)
{
	if (element == "param")
	{

		std::string distribute = attributes.stringValue("template", "block"); /* Extend for template tokenizing */
		std::istringstream distributeStream(distribute);
		std::vector<ParameterMapping> mapping;
		std::string distributeName;

		std::string templateName;
		std::getline(distributeStream,templateName,'(');

		distribute.erase(distribute.begin(),distribute.begin()+templateName.size()+1);
		distribute.erase(distribute.end()-1,distribute.end());

		distributeStream.str(distribute);

		while ( std::getline(distributeStream,distributeName,',') )
		{
			if (distributeName == "block")
				mapping.push_back(PARAM_MAP_BLOCK);
			else if (distributeName == "cyclic")
				mapping.push_back(PARAM_MAP_CYCLIC);
			else
				mapping.push_back(PARAM_MAP_BLOCK);

		}

		string align = attributes.stringValue("align");
		std::istringstream alignStream(align);
		std::string DataAlign;
		std::string TemplateAlign;
		std::string alignName;

		std::getline(alignStream,alignName,':');
		DataAlign = alignName;
		std::getline(alignStream,alignName,':');
		TemplateAlign = alignName;


		string variableNames = attributes.stringValue("name");
		std::istringstream nameStream(variableNames);
		std::string nameAndsize;

		while ( std::getline(nameStream,nameAndsize,';') )
		{
			mList.mDistribute.push_back(DistributeParam());
			DistributeParam& ref = mList.mDistribute.back();

			std::string copyNameandSize(nameAndsize);
			std::istringstream tmpStream(copyNameandSize);
			std::string name;
			std::getline(tmpStream,name,'(');

			copyNameandSize.erase(copyNameandSize.begin(),copyNameandSize.begin()+name.size()+1);
			copyNameandSize.erase(copyNameandSize.end()-1,copyNameandSize.end());

			std::istringstream sizeStream(copyNameandSize);
			std::vector<int> vsize;
			std::string size;
			while ( std::getline(sizeStream,size,',') )
			{
				vsize.push_back(atoi(size.c_str()));
			}
			ref.setSize(vsize);
			ref.setName(name);
			ref.setTemplateName(templateName);
			ref.setMapping(mapping);
			ref.setDataAlign(DataAlign);
			ref.setTemplateAlign(TemplateAlign);

		}


	}
}

}
}
